@@ -16,6 +16,20 @@ __all__ = [
 ]
 
 
+def get_version() -> str:
+    """
+    Gets the git version
+
+        :raises GitException: Error to do with git
+        :return: The version
+    """
+    args = ("git", "version")
+    process_status = subprocess.run(args, capture_output=True)
+    if process_status.returncode != 0:
+        raise GitException(process_status.stderr.decode())
+    return process_status.stdout.decode().strip()
+
+
 def init_repo(
         repo_dir: Path,
         repo_name: str,
